@@ -146,7 +146,7 @@ def backtest(address: str, startfrom: int, network: int, range_min: float, range
 
     # Calculate volatility based on price
     window_size = 24  #  Daily volatility
-    # Calculate rolling volatility with a daily rolling window and annualize results
+    # Calculate rolling volatility with a daily rolling window and annualize dpd
     dpd['volatility0_ann'] = dpd['price0'].pct_change().rolling(
         window_size).std()*(252**0.5)
 
@@ -272,32 +272,43 @@ def get_token_amounts_and_IL(dataframe: pd.DataFrame,
 
     dpd['HODL'] = dpd['amount0'].iloc[0] + dpd['close'] * dpd['amount1'].iloc[0]
     dpd['amountV'] = (dpd['amount0']) + (dpd['amount1'] * dpd['close'])
+    
     dpd['IL_5050'] = (dpd['amountV']  / dpd['HODL'] - 1) * 100
+
     hodl_value_100_token0 = (dpd['amount0'].iloc[0] + dpd['amount1'].iloc[0] * dpd['close'].iloc[0])
     dpd['IL_100_token0'] = (dpd['amountV'] - hodl_value_100_token0) / hodl_value_100_token0 * 100
+
     hodl_value_100_token1 = (dpd['amount0'].iloc[0] / dpd['close'].iloc[0]) + dpd['amount1'].iloc[0]
     dpd['IL_100_token1'] = (dpd['amountV'] - hodl_value_100_token1 * dpd['close']) / dpd['close'] * 100
+    
+    hedge_initial_value = dpd['amount1'].iloc[0] * dpd['close'].iloc[0]
+    dpd['amountHedge'] = hedge_initial_value - (hedge_initial_value * (dpd['close'] / dpd['close'].iloc[0]))
+    dpd['IL_5050_w_hedge'] = ((dpd['amountV'] + dpd['amountHedge']) / dpd['HODL'] - 1) * 100
+
+    hodl_value_100_token0 = (dpd['amount0'].iloc[0] + dpd['amount1'].iloc[0] * dpd['close'].iloc[0])
+    dpd['IL_100_token0'] = (dpd['amountV'] - hodl_value_100_token0) / hodl_value_100_token0 * 100
+    dpd['IL_100_token0_w_hedge'] = (dpd['amountV'] + dpd['amountHedge'] - hodl_value_100_token0) / hodl_value_100_token0 * 100
+
+    hodl_value_100_token1 = (dpd['amount0'].iloc[0] / dpd['close'].iloc[0]) + dpd['amount1'].iloc[0]
+    dpd['IL_100_token1'] = (dpd['amountV'] - hodl_value_100_token1 * dpd['close']) / dpd['close'] * 100
+    dpd['IL_100_token1_w_hedge'] = (dpd['amountV'] + dpd['amountHedge'] - hodl_value_100_token1 * dpd['close']) / dpd['close'] * 100
 
     return dpd
     
 
-def get_range_min_max_prices(dpd: pd.DataFrame, range_min: float, range_max: float) -> pd.DataFrame:
+def get_range_min_max_prices(dpd: pd.DataFrame, range_min: float, range_max: float, current_price: float) -> pd.DataFrame:
     df_artificial_dpd = dpd.copy()
 
     # Get DataFrame to be able to split into 3 pieces
     modulo = 3
     fx = df_artificial_dpd.shape[0] % modulo
     if fx == 1 or fx == 2:
-    df_artificial_dpd = df_artificial_dpd.iloc[: - fx]
-
-
-    # Get midprice
-    mid_price = (range_max + range_min) / 2
+        df_artificial_dpd = df_artificial_dpd.iloc[: - fx]
 
     # Generate artificial prices by covering all price ranges
-    s1 = np.linspace(mid_price, range_max, int(dpd.shape[0]/3))
+    s1 = np.linspace(current_price, range_max, int(dpd.shape[0]/3))
     s2 = np.linspace(range_max, range_min, int(dpd.shape[0]/3))
-    s3 = np.linspace(range_min, mid_price, int(dpd.shape[0]/3))
+    s3 = np.linspace(range_min, current_price, int(dpd.shape[0]/3))
     df_artificial_dpd['close'] = np.concatenate((s1, s2, s3))
 
     return df_artificial_dpd
\ No newline at end of file
