@@ -121,4 +121,4 @@ def graph(network: str, address: str, fromdate: int) -> pd.DataFrame:
     print("Query succeeded.")
     print("-------------------------------- GraphQL Query --------------------------------")
 
-    return df
+    return df.astype(float)
